%define name    horde
%define version 3.1.3
%define release %mkrel 1

Name:       %{name}
Version:    %{version}
Release:    %{release}
Summary:    The Horde framework
License:    GPL
Group:      System/Servers
Source0:    ftp://ftp.horde.org/pub/horde/%{name}-%{version}.tar.bz2
Patch2:     %{name}-3.0.2-better-default-configuration.patch
Patch4:     %{name}-3.1.1-registry.patch
URL:        http://www.horde.org/
Requires:   apache-mod_php
Requires:   php-xml
Requires:   php-dom
# webapp macros and scriptlets
%if %mdkversion < 200700
%define _webconfdir %{_sysconfdir}/httpd/conf
%define _webappconfdir %_webconfdir/webapps.d
Requires(post): rpm-helper
Requires(postun): rpm-helper
BuildRequires: rpm-helper
BuildRequires: rpm-mandriva-setup
%else
Requires(post):     rpm-helper >= 0.16
Requires(postun):   rpm-helper >= 0.16
BuildRequires:  rpm-helper >= 0.16
BuildRequires:  rpm-mandriva-setup >= 1.23
%endif
Conflicts:  horde-accounts <= 2.1.2
Conflicts:  horde-forwards <= 2.2.2
Conflicts:  horde-password <= 2.2.2
Conflicts:  horde-vacation <= 2.2.2
BuildArch:  noarch
BuildRoot:  %{_tmppath}/%{name}-%{version}

%description
The Horde Framework provides a common structure and interface for Horde
applications (such as IMP, a web-based mail program).  This RPM is required
for all other Horde module RPMS.

The Horde Project writes web applications in PHP and releases them under
the GNU Public License.  For more information (including help with Horde
and its modules) please visit http://www.horde.org/.

%prep
%setup -q
%patch2
%patch4

# fix perms
chmod 755 scripts/*.{php,sh,cron}

# fix encoding
for file in `find . -type f`; do
    perl -pi -e 'BEGIN {exit unless -T $ARGV[0];} s/\r\n$/\n/;' $file
done

%build

%install
rm -rf %{buildroot}

# apache configuration
install -d -m 755 %{buildroot}%{_webappconfdir}
cat > %{buildroot}%{_webappconfdir}/%{name}.conf <<EOF
# %{name} Apache configuration file
Alias /%{name} %{_var}/www/%{name}
<Directory %{_var}/www/%{name}>
    Allow from all
</Directory>
EOF

# remove .htaccess files
find . -name .htaccess -exec rm -f {} \;

# install files
install -d -m 755 %{buildroot}%{_var}/www/%{name}
install -d -m 755 %{buildroot}%{_datadir}/%{name}
install -d -m 755 %{buildroot}%{_sysconfdir}
cp -pR *.php %{buildroot}%{_var}/www/%{name}
cp -pR admin %{buildroot}%{_var}/www/%{name}
cp -pR js %{buildroot}%{_var}/www/%{name}
cp -pR services %{buildroot}%{_var}/www/%{name}
cp -pR themes %{buildroot}%{_var}/www/%{name}
cp -pR util %{buildroot}%{_var}/www/%{name}
cp -pR lib %{buildroot}%{_datadir}/%{name}
cp -pR locale %{buildroot}%{_datadir}/%{name}
cp -pR scripts %{buildroot}%{_datadir}/%{name}
cp -pR templates %{buildroot}%{_datadir}/%{name}
cp -pR config %{buildroot}%{_sysconfdir}/%{name}

# use symlinks to recreate original structure
pushd %{buildroot}%{_var}/www/%{name}
ln -s ../../..%{_sysconfdir}/%{name} config
ln -s ../../..%{_datadir}/%{name}/lib .
ln -s ../../..%{_datadir}/%{name}/locale .
ln -s ../../..%{_datadir}/%{name}/templates .
popd
pushd %{buildroot}%{_datadir}/%{name}
ln -s ../../..%{_sysconfdir}/%{name} config
popd

# activate configuration files
for file in %{buildroot}%{_sysconfdir}/%{name}/*.dist; do
    mv $file ${file%.dist}
done

# fix script shellbang
for file in `find %{buildroot}%{_datadir}/%{name}/scripts`; do
    perl -pi -e 's|/usr/local/bin/php|/usr/bin/php|' $file
done

# registry dir
install -d -m 755 %{buildroot}%{_sysconfdir}/%{name}/registry.d

# logs
install -d -m 755 %{buildroot}%{_var}/log/%{name}
install -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d
cat > %{buildroot}%{_sysconfdir}/logrotate.d/%{name} <<EOF
%{_var}/log/%{name}/*.log {
    missingok
    compress
}
EOF

cat > README.mdv <<EOF
Mandriva RPM specific notes

setup
-----
The setup used here differs from default one, to achieve better FHS compliance.
- the configuration files are in /etc/horde
- the log files are in /var/log/horde
- the files accessibles from the web are in /var/www/horde
- the files non accessibles from the web are in /usr/share/horde

post-installation
-----------------
You have to either use a browser to http://your.server.url/horde, so as to
configure proper configuration.

Additional useful packages
--------------------------
- either a SQL database (MySQL or PostgreSQL), an LDAP (openldap) or a Kolab
  server for storing preferences
- php-mcrypt for better encryption
- php-iconv and php-mbstring for better utf8 support
- php-gd for image manipulations
- php-pear-File for CVS import support
- php-Date to deal with calendar data
- php-Services_Weather to the weather.com block on the portal page


Additional horde applications
-----------------------------
They are all packaged as horde-<application>. Warning, some have still not been
ported to horde 3, and have been removed from the distribution (vacation,
forwards and accounts notably).
EOF

%clean
rm -rf %{buildroot}

%post
%if %mdkversion < 200700
if [ "$1" = "1" ]; then
	/sbin/service httpd condrestart
fi
%else
%_post_webapp
%endif

if [ $1 = 1 ]; then
    # configuration
    %create_ghostfile %{_sysconfdir}/%{name}/conf.php.bak apache apache 644
fi

%postun
%if %mdkversion < 200700
if [ "$1" = "0" ]; then
	/sbin/service httpd condrestart
else
	/sbin/service httpd condreload
fi
%else
%_postun_webapp
%endif

%files
%defattr(-,root,root)
%doc README README.mdv COPYING docs  scripts/SCRIPTS
%config(noreplace) %{_webappconfdir}/%{name}.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/%{name}
%attr(-,apache,apache) %config(noreplace) %{_sysconfdir}/%{name}/conf.php 
%{_datadir}/%{name}
%{_var}/www/%{name}
%attr(-,apache,apache) %{_var}/log/%{name}

%changelog
* Fri Aug 25 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.1.3-1mdv2007.0
- New version 3.1.3

* Fri Aug 11 2006 Andreas Hasenack <andreas@mandriva.com> 3.1.2-2mdv2007.0
- make somewhat backportable

* Mon Jul 10 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.1.2-1mdv2007.0
- New version 3.1.2

* Fri Jun 30 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.1.1-3mdv2007.0
- relax buildrequires versionning

* Mon Jun 26 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.1.1-2mdv2007.0
- new webapp macros 
- decompress all patches
- use herein document for README.mdv

* Wed Mar 29 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.1.1-1mdk
- New release 3.1.1
- rediff registry patch

* Tue Mar 07 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.1-1mdk
- new version
- pre-10.2 compatibility
- drop non-interactive setup patch, unused anway
- rediff registry patch

* Wed Jan 11 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.0.9-2mdk
- add conflict with horde 2 applications
- update README.mdk with application packages mention

* Tue Dec 27 2005 Guillaume Rousse <guillomovitch@mandriva.org> 3.0.9-1mdk
- New release 3.0.9
- %%mkrel

* Wed Nov 02 2005 Guillaume Rousse <guillomovitch@mandriva.org> 3.0.6-1mdk
- New release 3.0.6
- rediff patches 1 and 4

* Fri Aug 19 2005 Guillaume Rousse <guillomovitch@mandriva.org> 3.0.5-1mdk
- New release 3.0.5
- rediff patch 4
- better fix encoding
- drop manual pear requires

* Wed Jun 29 2005 Guillaume Rousse <guillomovitch@mandriva.org> 3.0.4-3mdk 
- better requires
- better fix encoding
- fix requires
- use new rpm macros
- fix scripts shellbang

* Mon Jun 13 2005 Guillaume Rousse <guillomovitch@mandriva.org> 3.0.4-2mdk 
- new apache setup
- requires

* Sat Apr 16 2005 Guillaume Rousse <guillomovitch@mandrake.org> 3.0.4-1mdk
- New release 3.0.4

* Fri Feb 18 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 3.0.2-4mdk
- spec file cleanups, remove the ADVX-build stuff
- strip away annoying ^M

* Thu Jan 27 2005 Guillaume Rousse <guillomovitch@mandrake.org> 3.0.2-3mdk 
- reload apache instead of restarting it
- no more automatic config generation, incorrect default values
- README.mdk
- spec cleanup
- don't touch log file, make log dir owned by apache

* Mon Jan 17 2005 Guillaume Rousse <guillomovitch@mandrake.org> 3.0.2-2mdk 
- herein document instead of external source for apache config
- fix inclusions from %{_datadir}/%{name}
- fix configuration perms
- generate configuration at postinstall
- better default configuration (logs)
- rpm-helper is now a prereq

* Thu Jan 13 2005 Guillaume Rousse <guillomovitch@mandrake.org> 3.0.2-1mdk 
- New version
- top-level is now %{_var}/www/%{name}
- config is now in %{_sysconfdir}/%{name}
- other non-accessible files are now in %{_datadir}/%{name}
- drop safemode build
- drop patches 0, 2 and 3
- rediff patch 4
- drop old obsoletes
- clean up redundant requires
- no more order for apache configuration

* Tue Oct 26 2004 Guillaume Rousse <guillomovitch@mandrakesoft.com> 2.2.7-1mdk
- New release 2.2.7

* Mon Sep 27 2004 Guillaume Rousse <guillomovitch@mandrakesoft.com> 2.2.6-1mdk
- New release 2.2.6
- rpmbuildupdate aware

* Sun Jul 18 2004 Guillaume Rousse <guillomovitch@mandrake.org> 2.2.5-3mdk 
- apache config file in %{_sysconfdir}/httpd/webapps.d

* Sat May 01 2004 Guillaume Rousse <guillomovitch@mandrake.org> 2.2.5-2mdk
- registry patch (stolen from Debian)
- standard perms for %{_sysconfdir}/httpd/conf.d/%{order}_%{name}.conf
- don't provide useless ADVXpackage virtual package

* Mon Apr 05 2004 Guillaume Rousse <guillomovitch@mandrake.org> 2.2.5-1mdk
- new version
- dropped original configuration patch, it's up to application packages to
  register themselves
- fixed sendmail path in configuration

* Sat Dec 20 2003 Guillaume Rousse <guillomovitch@mandrake.org> 2.2.4-2mdk
- untagged localisation files
- no more .htaccess files, use %{_sysconfdir}/httpd/conf.d/%{order}_%{name}.conf instead
- scripts now in  %{_datadir}/{name}
- passwd module externalized in its own package

* Sun Sep 14 2003 Guillaume Rousse <guillomovitch@linux-mandrake.com> 2.2.4-1mdk
- 2.2.4

* Tue Sep 09 2003 Guillaume Rousse <guillomovitch@linux-mandrake.com> 2.2.3-3mdk
- changed name to horde, old version doesn't exist anymore
- standard perms and ownership for config files, access is already denied

* Mon Sep 08 2003 Guillaume Rousse <guillomovitch@linux-mandrake.com> 2.2.3-2mdk
- spec cleanup
- remove useless files from webroot (.dist, doc files, .po)
- properly tag localisation files
- drop apache1 integration
- remove implicit dependencies

* Fri Jun 27 2003 Giuseppe Ghib <ghibo@mandrakesoft.com> 2.2.3-1mdk
- Release 2.2.3.
- Readapted Patch0.
- Updated Passwd to 2.2.
- Added "safe_mode Off" and "session.bug_compat_42 Off" for PHP, to
  horde-mdk.conf.
- Modified Patch0 to get logs to syslog facilities.

* Sun Feb 16 2003 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.2.1-2mdk
- new macros from ADVX-build

* Sun Feb 16 2003 Jean-Michel Dault <jmdault@mandrakesoft.com> 2.2.1-1mdk
- New version, required by PHP 4.3.0
- fix post scripts
- fix config file
- add Errordocument 404 directives so users know they have to install turba
  and imp3.

* Wed Jun 19 2002 Lenny Cartier <lenny@mandrakesoft.com> 2.1-1mdk
- updated by David Walser <luigiwalser@yahoo.com> :
    - 2.1 final

* Sat Mar 18 2002 David Walser <luigiwalser@yahoo.com> 2.1-0.1mdk
- Regenerate patches
- Remove admin directory from files (no longer exists)

* Mon Mar 11 2002 Giuseppe Ghib <ghibo@mandrakesoft.com> 2.0-4mdk
- fixed php /usr/share/php -> /usr/lib/php according to php-devel
  path.

* Mon Mar 11 2002 Giuseppe Ghib <ghibo@mandrakesoft.com> 2.0-3mdk
- renamed to horde2, so to maintain version 1.2.X.

* Mon Mar 11 2002 Giuseppe Ghib <ghibo@mandrakesoft.com> 2.0-2mdk
- changed some config file with predefined values.
- added ppphp-xml to Requires.
- included passwd module.

* Sun Mar 10 2002 Giuseppe Ghib <ghibo@mandrakesoft.com> 2.0-1mdk
- 2.0.

* Wed Jan 02 2002 Brent J. Nordquist <bjn@horde.org>
- 2.0 release 1

* Wed Sep 12 2001 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.2.6-3mdk
- replaced pg_connect with pg_pconnect in db.pgsql, to avoid the
  warning "...is not a valid PostgreSQL link resource".

* Tue Sep 11 2001 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.2.6-2mdk
- added php-pgsql to horde-pgsql Requires.

* Tue Sep 04 2001 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.2.6-1mdk
- updated to release 1.2.6.

* Wed Aug 29 2001 Philippe Libat <philippe@mandrakesoft.com> 1.2.4-3mdk
- fix httpd.conf entry

* Mon Feb 26 2001 Giuseppe Ghibo' <ghibo@mandrakesoft.com> 1.2.4-2mdk
- add mod_php to Requires.

* Sat Feb 24 2001 Giuseppe Ghibo' <ghibo@mandrakesoft.com> 1.2.4-1mdk
- initial mandrake release.

* Tue Feb 06 2001 Brent J. Nordquist <bjn@horde.org>
- 1.2.4 release 1rh7
